'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var Dock = _interopDefault(require('react-dock'));
var parseKey = _interopDefault(require('parse-key'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var POSITIONS = ['left', 'top', 'right', 'bottom'];

var DockMonitor = function DockMonitor(props) {
  var toggleVisibilityKey = props.toggleVisibilityKey,
      changePositionKey = props.changePositionKey,
      changeMonitorKey = props.changeMonitorKey,
      children = props.children,
      _props$defaultIsVisib = props.defaultIsVisible,
      defaultIsVisible = _props$defaultIsVisib === void 0 ? true : _props$defaultIsVisib,
      _props$defaultPositio = props.defaultPosition,
      defaultPosition = _props$defaultPositio === void 0 ? 'right' : _props$defaultPositio,
      _props$defaultSize = props.defaultSize,
      defaultSize = _props$defaultSize === void 0 ? 0.3 : _props$defaultSize,
      _props$fluid = props.fluid,
      fluid = _props$fluid === void 0 ? true : _props$fluid;

  var _useState = React.useState(defaultIsVisible),
      isVisible = _useState[0],
      setIsVisible = _useState[1];

  var _useState2 = React.useState(defaultPosition),
      position = _useState2[0],
      setPosition = _useState2[1];

  var _useState3 = React.useState(defaultSize),
      size = _useState3[0],
      setSize = _useState3[1];

  var _useState4 = React.useState(0),
      childMonitorIndex = _useState4[0],
      setChildMonitorIndex = _useState4[1];

  var childrenCount = React.Children.count(children);

  if (childrenCount === 0) {
    // eslint-disable-next-line no-console
    console.error('<DockMonitor> requires at least one monitor inside. ' + 'Why don’t you try <LogMonitor>? You can get it at ' + 'https://github.com/reduxjs/redux-devtools/tree/master/packages/redux-devtools-log-monitor.');
  } else if (childrenCount > 1 && !changeMonitorKey) {
    // eslint-disable-next-line no-console
    console.error('You specified multiple monitors inside <DockMonitor> ' + 'but did not provide `changeMonitorKey` prop to change them. ' + 'Try specifying <DockMonitor changeMonitorKey="ctrl-m" /> ' + 'and then press Ctrl-M.');
  }

  var matchesKey = function matchesKey(key, event) {
    if (!key) {
      return false;
    }

    var charCode = event.keyCode || event.which;

    var _char = String.fromCharCode(charCode);

    return key.name.toUpperCase() === _char.toUpperCase() && key.alt === event.altKey && key.ctrl === event.ctrlKey && key.meta === event.metaKey && key.shift === event.shiftKey;
  };

  var handleKeyDown = React.useCallback(function (e) {
    // Ignore regular keys when focused on a field
    // and no modifiers are active.
    if (!e.ctrlKey && !e.metaKey && !e.altKey && (e.target.tagName === 'INPUT' || e.target.tagName === 'SELECT' || e.target.tagName === 'TEXTAREA' || e.target.isContentEditable)) {
      return;
    }

    var visibilityKey = parseKey(toggleVisibilityKey);
    var positionKey = parseKey(changePositionKey);
    var monitorKey;

    if (changeMonitorKey) {
      monitorKey = parseKey(changeMonitorKey);
    }

    if (matchesKey(visibilityKey, e)) {
      e.preventDefault();
      setIsVisible(!isVisible);
    } else if (matchesKey(positionKey, e)) {
      e.preventDefault();
      var nextPositionIndex = (POSITIONS.indexOf(position) + 1) % POSITIONS.length;
      setPosition(POSITIONS[nextPositionIndex]);
    } else if (matchesKey(monitorKey, e)) {
      e.preventDefault();
      setChildMonitorIndex((childMonitorIndex + 1) % React.Children.count(children));
    }
  }, [changeMonitorKey, changePositionKey, childMonitorIndex, children, isVisible, position, toggleVisibilityKey]);

  var handleSizeChange = function handleSizeChange(requestedSize) {
    setSize(requestedSize);
  };

  var renderChild = function renderChild(child, index, otherProps) {
    if (index !== childMonitorIndex) {
      return null;
    }

    return React.cloneElement(child, _extends({}, otherProps));
  };

  React.useEffect(function () {
    window.addEventListener('keydown', handleKeyDown);
    return function () {
      window.removeEventListener('keydown', handleKeyDown);
    };
  }, [handleKeyDown]);
  return React__default.createElement(Dock, {
    position: position,
    isVisible: isVisible,
    size: size,
    fluid: fluid,
    onSizeChange: handleSizeChange,
    dimMode: "none"
  }, React.Children.map(children, function (child, index) {
    return renderChild(child, index, props);
  }));
};

exports.default = DockMonitor;
//# sourceMappingURL=recoil-devtools-dock.cjs.development.js.map
